@@ -5,8 +5,8 @@ use Carp;
 
 sub _elements {
     my ($class, $self, $name, $elements) = @_;
-    croak "missing key function for elements" unless
-        defined($elements->[1]) || $self->isa("Heap::Simple::Wrapper");
+    croak "missing key function for elements $self" unless
+        defined($elements->[1]) || $class->isa("Heap::Simple::Wrapper");
     $self->[0][2] = $elements->[1];
     return $name;
 }
